@@ -16,6 +16,8 @@ pub struct ConsoleEngine {
     input: termion::input::Keys<termion::AsyncReader>,
     output: termion::raw::RawTerminal<Stdout>,
     time_limit: u128,
+    /// The current frame count, publicly accessible
+    pub frame_count: usize,
     width: u32,
     height: u32,
     screen: Vec<Pixel>,
@@ -42,7 +44,7 @@ pub struct ConsoleEngine {
 ///         engine.wait_frame(); // wait for next frame + capture inputs
 ///         engine.clear_screen(); // reset the screen
 ///     
-///         engine.line(0, 0, 19, 9, pixel::pxl('#')); // draw a line of '#' from [0,0] to [9,9]
+///         engine.line(0, 0, 19, 9, pixel::pxl('#')); // draw a line of '#' from [0,0] to [19,9]
 ///         engine.print(0, 4, format!("Result: {}", value)); // prints some value at [0,4]
 ///     
 ///         engine.set_pxl(4, 0, pixel::pxl_fg('O', color::Cyan)); // write a majestic cyan 'O' at [4,0]
@@ -58,10 +60,12 @@ pub struct ConsoleEngine {
 impl ConsoleEngine {
     /// Initialize a screen of the provided width and height, and load the target FPS
     pub fn init(width: u32, height: u32, target_fps: u32) ->  ConsoleEngine {
+        assert!(target_fps > 0, "Target FPS needs to be greater than zero.");
         let mut my = ConsoleEngine {
             output: stdout().into_raw_mode().unwrap(),
             input: termion::async_stdin().keys(),
             time_limit: (1000/target_fps) as u128,
+            frame_count: 0,
             width: width,
             height: height,
             screen: vec![pixel::pxl(' '); (width*height) as usize],
@@ -77,11 +81,13 @@ impl ConsoleEngine {
     
     /// Initialize a screen filling the entire terminal with the target FPS
     pub fn init_fill(target_fps: u32) -> ConsoleEngine {
+        assert!(target_fps > 0, "Target FPS needs to be greater than zero.");
         let size = termion::terminal_size().unwrap();
         let mut my = ConsoleEngine {
             output: stdout().into_raw_mode().unwrap(),
             input: termion::async_stdin().keys(),
             time_limit: (1000/target_fps) as u128,
+            frame_count: 0,
             width: size.0 as u32,
             height: size.1 as u32,
             screen: vec![pixel::pxl(' '); (size.0*size.1) as usize],
@@ -135,7 +141,7 @@ impl ConsoleEngine {
     /// 
     /// usage:
     /// ```
-    /// engine.print(0,0,"Hello, world!");
+    /// engine.print(0,0, String::from("Hello, world!"));
     /// engine.print(0, 4, format!("Score: {}", score));
     /// ```
     pub fn print(&mut self, x: u32, y: u32, string: String)
@@ -157,9 +163,9 @@ impl ConsoleEngine {
     /// usage
     /// ```
     /// // print "Hello, world" in blue on white background
-    /// engine.print(0,0,"Hello, world!", color::Blue, color::White);
+    /// engine.print(0,0, String::from("Hello, world!"), color::Blue, color::White);
     /// ```
-    pub fn print_fbg<C: color::Color + Clone>(&mut self, x: u32, y: u32, string: String, fg: C, bg: C)
+    pub fn print_fbg<C1: color::Color + Clone, C2: color::Color + Clone>(&mut self, x: u32, y: u32, string: String, fg: C1, bg: C2)
     {
         if x < self.width && y < self.height {
             let pos = self.coord_to_index(x, y);
@@ -226,7 +232,7 @@ impl ConsoleEngine {
 			}
         } else { 
             let y_end: i32;
-            if delta_x >= 0
+            if delta_y >= 0
 			    { x = start_x as i32; y = start_y as i32; y_end = end_y as i32; }
 			else
                 { x = end_x as i32; y = end_y as i32; y_end = start_y as i32; }
@@ -297,7 +303,7 @@ impl ConsoleEngine {
     /// 
     /// usage:
     /// ```
-    /// engine.print(0,0,"Hello, world!"); // <- prints "Hello, world!" in 'screen' memory
+    /// engine.print(0,0,String::from("Hello, world!")); // <- prints "Hello, world!" in 'screen' memory
     /// engine.draw(); // display 'screen' memory to the user's terminal
     /// ```
     pub fn draw(&self)
@@ -333,9 +339,10 @@ impl ConsoleEngine {
         if self.time_limit > self.instant.elapsed().as_millis() {
             std::thread::sleep(std::time::Duration::from_millis(((self.time_limit - self.instant.elapsed().as_millis()) % self.time_limit) as u64));
         }
-
         self.instant = std::time::Instant::now();
         
+        self.frame_count += 1;
+
         let mut c = self.input.next();
         let mut count = 0;
         while c.is_some() && count < 10 { // cannot support for more than 10 key presses at the same time
